# PNP CCV

## Develop

```
uv pip install -e suap_pnp_ccv
```

## Release

````
python setup.py sdist
twine upload "dist/suap_pnp_ccv-0.0.2.tar.gz" -u __token__ -p $PIP_ACCESS_TOKEN
```

## Install

````
pip install suap_pnp_ccv
```

## Documentation

https://docs.google.com/document/d/17NB_XUp5IpxtOZDz8vmBLMF7O0bNfraT6MSlG2Tx0P4/edit?tab=t.0

